proste_route_animation_class library
Classes
- FadeRouteAnimation
- Using FadeTransition to realize route animation route is Required parameters, other is Optional parameters
- RotationRouteAnimation
- Using RotationTransition to realize route animation route is Required parameters, other is Optional parameters
- ScaleRouteAnimation
- Using ScaleTransition to realize route animation route is Required parameters, other is Optional parameters
- SizeRouteAnimation
- Using SizeRouteTransition to realize route animation route is Required parameters, other is Optional parameters
- SlideRouteAnimation
- Using SlideTransition to realize route animation route is Required parameters, other is Optional parameters